/**
 * @file
 * Defines Javascript behaviors for the textfield_confirm module.
 */

/**
 * Attaches the behavior to each input element.
 */
Drupal.behaviors.textfieldConfirm = function (context) {
  "use strict";

  $(context).find("input.textfield-confirm-field:not(.textfield-confirm-processed)").each(function () {
    Drupal.textfieldConfirm.processInput(this, Drupal.settings.textfield_confirm);
  }).addClass("textfield-confirm-processed");
};

Drupal.textfieldConfirm = Drupal.textfieldConfirm || {};

/**
 * Adds checking behavior to textfield input elements.
 */
Drupal.textfieldConfirm.processInput = function (element, settings) {

  "use strict";

  var $primary = $(element);

  var $secondary = $primary.parent().parent().find('input.textfield-confirm-confirm');
  var $helpText = $('<span class="textfield-confirm-help-text"></span>');
  $secondary.after($helpText);

  // Checks the text fields.
  var textfieldConfirmCheck = function () {
    // Remove timers for a delayed check if they exist.
    if (this.timer) {
      clearTimeout(this.timer);
    }

    // Verify that there is a value to check.
    if (!$primary.val()) {
      $helpText.hide();
      return;
    }

    var message = $primary.val() === $secondary.val() ? settings.success : settings.error;

    if ($helpText.html() != message) {
      $helpText.html(message);
    }

    $helpText.show();
  };

  var textfieldConfirmDelayedCheck = function () {
    // Postpone the check since the user is most likely still typing.
    if (this.timer) {
      clearTimeout(this.timer);
    }

    // When the user clears the field, hide the tips immediately.
    if (!$primary.val()) {
      $helpText.hide();
      return;
    }

    // Schedule the actual check.
    this.timer = setTimeout(textfieldConfirmCheck, 100);
  };

  // Monitor keyup and blur events. Blur must be used because a mouse paste
  // does not trigger keyup.
  $primary.keyup(textfieldConfirmDelayedCheck).blur(textfieldConfirmCheck);
  $secondary.keyup(textfieldConfirmDelayedCheck).blur(textfieldConfirmCheck);
};
